package com.muyu.cloud.mart.controller;

import com.alibaba.fastjson.JSON;
import com.muyu.cloud.mart.service.MarketService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.domain.Market;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author：chaiyapeng
 * @Package：com.muyu.cloud.etl.controller
 * @Project：cloud-mart
 * @name：MarketController
 * @Date：2024/8/21 21:53
 */
@RestController
@RequestMapping("list")
public class MarketController extends BaseController {

    @Autowired
    private MarketService marketService;
    @Autowired
    private RedisTemplate<String,String>redisTemplate;

//    @RequiresPermissions("mart:info:list")
    @GetMapping("findMarketList")
    public Result<TableDataInfo<Market>> findMarketList(Market market){
        if (redisTemplate.hasKey("list")){
            List<String> list = redisTemplate.opsForList().range("list", 0, -1);
            ArrayList<Market> markets = new ArrayList<>();
            for (String s : list) {
                markets.add(JSON.parseObject(s, Market.class));
            }
            redisTemplate.delete("list");
            return getDataTable(markets);
        }

        startPage();
        List<Market> list = marketService.findMarketList(market);
        for (Market market1 : list) {
            redisTemplate.opsForList().rightPush("list", JSON.toJSONString(market1));
        }
        return getDataTable(list);
    }

    @GetMapping("selectMobileAddress")
    //查询手机号码所属地区
    public static String getMobileAddress(String mobile) throws Exception
    {
        String address = "";
        try
        {
            mobile = mobile.trim();
            if (mobile.matches("^(13|15|18)\\d{9}$") || mobile.matches("^(013|015|018)\\d{9}$")) //以13，15，18开头，后面九位全为数字
            {
                String url = "http://172.13.1.1:8080/datamart?action=mobile&mobile=" + mobile;
                URLConnection connection = (URLConnection) new URL(url).openConnection();
                connection.setDoOutput(true);
                InputStream os = connection.getInputStream();
                Thread.sleep(100);
                int length = os.available();
                byte[] buff = new byte[length];
                os.read(buff);
                String s = new String(buff, "gbk");
                int len = s.indexOf("卡号归属地");
                s = s.substring(len, len+100);
                len = s.lastIndexOf("</TD>");
                address = s.substring(0, len);
                len = address.lastIndexOf(">");
                address = address.substring(len+1, address.length());
                address = address.replace(" ", ",");
                address = address.replace("d> -->", "");
                address = address.replace(" -->", "");
                address = address.replace("-->", "");
                s = null;
                buff = null;
                os.close();
                connection = null;
            }
        }
        catch(Exception e)
        {
            address = "未知";
            System.out.println("手机所属地查询失败====================");
        }
        return address;
    }
}
